"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExitManager = exports.registerExitCleanUp = void 0;
const cleanUpHandlers = [];
function registerExitCleanUp(fn) {
    cleanUpHandlers.push(fn);
}
exports.registerExitCleanUp = registerExitCleanUp;
class ExitManager {
    constructor(log) {
        this.log = log;
        process.stdin.resume(); //so the program will not close instantly
        //do something when app is closing
        process.on('exit', this.exitHandler.bind(this));
        //catches ctrl+c event
        process.on('SIGINT', this.exitHandler.bind(this));
        // catches "kill pid" (for example: nodemon restart)
        process.on('SIGUSR1', this.exitHandler.bind(this));
        process.on('SIGUSR2', this.exitHandler.bind(this));
        //catches uncaught exceptions
        process.on('uncaughtException', this.exitHandler.bind(this));
    }
    exitHandler(options, err) {
        for (const fn of cleanUpHandlers) {
            try {
                fn();
            }
            catch (err) {
                this.log.info('Failed to call cleanup function ' + err);
            }
        }
        if (err) {
            this.log.info(err);
        }
        process.exit();
    }
}
exports.ExitManager = ExitManager;
//# sourceMappingURL=exit.js.map